@@ -1,8 +1,8 @@
 from pathlib import Path
-from typing import Any, List, Tuple
+from typing import Any
 from PySide6.QtWidgets import QFrame, QListWidgetItem, QFileDialog
 from PySide6.QtCore import Signal, Slot, QModelIndex
-from .choose_project_frame_ui import Ui_ChooseProjectFrame
+from voice_annotation_tool.choose_project_frame_ui import Ui_ChooseProjectFrame
 
 
 class ChooseProjectFrame(QFrame, Ui_ChooseProjectFrame):
@@ -20,7 +20,7 @@ class ChooseProjectFrame(QFrame, Ui_ChooseProjectFrame):
         super().__init__()
         self.setupUi(self)
 
-    def load_recent_projects(self, paths: List[Path]):
+    def load_recent_projects(self, paths: list[Path]):
         """Loads the given paths into the list of recent projects."""
         for path in paths:
             item = QListWidgetItem(str(path))
@@ -28,7 +28,7 @@ class ChooseProjectFrame(QFrame, Ui_ChooseProjectFrame):
 
     @Slot()
     def open_project(self):
-        files: Tuple[str, Any] = QFileDialog.getOpenFileName(
+        files: tuple[str, Any] = QFileDialog.getOpenFileName(
             self, "Open Project", "", "Project Files (*.json)"
         )
         if not files[0]:
